@@ -110,7 +110,7 @@ class Robot:
                  "data": {"wxid": f"{accept_wxid}",
                           "name": f"{name}",
                           "author": f"{author}",
-                          "app": "wx5aa333606550dfd5",
+                          "app": "wx8dd6ecd81906fd84",
                           "jumpUrl": f"{jumpUrl}",
                           "musicUrl": f"{musicUrl}",
                           "imageUrl": f"{imageUrl}"},
@@ -118,6 +118,36 @@ class Robot:
 
         return self.post_(type_, data_)
 
+    def help(self):
+        str = """
+        QQ 2696047693[puthonnic]
+        
+        QQ群:769409487
+        
+        Software is like sex –– it's better when it's free.by Linus Torvalds.
+        开源是一件很cool的事情。给别人看自己写的代码，全世界不同地方的人来用自己写的软件，难道不是很cool吗
+        
+        感谢 Daen
+        
+        
+        """
+        print(str)
+
+
+class Constant:
+    Callback_Events={
+        "注入成功":"D0001",
+        "登录成功":"D0002",
+        "收到消息":"D0003"
+        ""
+    }
+
+    qqmusicapp="wx5aa333606550dfd5"
+    neteasymusicapp="wx8dd6ecd81906fd84"
+    kugoumysciapp="wx79f2c4418704b4f8"
+
+
+
 # a = Robot(url="http://127.0.0.1:7777/DaenWxHook/httpapi/", wxid="wxid_at1vbqt6zgg922")
 # bbb=a.get_friend_list()
 # print(bbb)
